@@ -8,7 +8,7 @@ from dataplane.pipelinerun.data_persist.s3_store import (
     pipeline_s3_store,
 )
 
-from dataplane import (
+from dataplane.hello import (
     hello,
 )
 
